# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module for Box.

Define class for information about backup, data copy and so on.
"""


from iobase.xmldata import (XmlNode)
from ionas.backupsync.info import (ConnectionInfo, TargetInfo,)


NAME_NAME = "name"
ID_NAME = "id"
CODE_NAME = "code"

TYPE_NAME = "type"
SUBDIR_NAME = "subdir"


class BoxConnectionInfo(ConnectionInfo):
    """Class for Box connection information."""

    def __init__(self, connection_xml):
        """Constructor."""

        super(BoxConnectionInfo, self).__init__(
                                    connection_xml.get_value(NAME_NAME))

        self.id = connection_xml.get_value(ID_NAME, "")
        self.code = connection_xml.get_value(CODE_NAME, "")


class BoxTargetInfo(TargetInfo):
    """Class for Box target information."""

    def __init__(self, target_xml, connection_xml):
        """Constructor."""

        super(BoxTargetInfo, self).__init__(
                                target_xml.get_value(TYPE_NAME),
                                BoxConnectionInfo(connection_xml))

        self.subdir = target_xml.get_value(SUBDIR_NAME, "")

    def get_root_path(self):
        return u"/"

    def get_target_name(self):
        target_name = "box_" + self.connection_info.name
        if isinstance(target_name, str):
            target_name = target_name.decode("UTF8")

        return target_name

    def do_wait_modified(self):
        return False
